@@ -50,8 +50,7 @@ func createDebugCmd() *cobra.Command {
 
 			cache.Init(os.Getenv("POSH_SHELL"))
 
-			_, reload := cache.Get[bool](cache.Device, config.RELOAD)
-			cfg := config.Get(flags.ConfigPath, reload)
+			cfg := getDebugConfig(configFlag)
 
 			template.Init(env, cfg.Var, cfg.Maps)
 
@@ -85,3 +84,12 @@ func createDebugCmd() *cobra.Command {
 
 	return debugCmd
 }
+
+func getDebugConfig(configpath string) *config.Config {
+	if len(configpath) != 0 {
+		return config.Load(configpath, false)
+	}
+
+	_, reload := cache.Get[bool](cache.Device, config.RELOAD)
+	return config.Get(configpath, reload)
+}
