@@ -62,7 +62,7 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 	initCmd.Flags().BoolVarP(&printOutput, "print", "p", false, "print the init script")
 	initCmd.Flags().BoolVarP(&strict, "strict", "s", false, "run in strict mode")
 	initCmd.Flags().BoolVar(&debug, "debug", false, "enable/disable debug mode")
-	initCmd.Flags().BoolVar(&eval, "eval", false, "output the prompt for eval")
+	initCmd.Flags().BoolVar(&eval, "eval", false, "output the full init script for eval")
 
 	_ = initCmd.MarkPersistentFlagRequired("config")
 
@@ -74,6 +74,12 @@ func runInit(sh, command string) {
 		log.Enable(plain)
 	}
 
+	if sh == "powershell" {
+		sh = shell.PWSH
+	}
+
+	initCache(sh)
+
 	cfg := config.Load(configFlag, false)
 
 	flags := &runtime.Flags{
@@ -90,8 +96,6 @@ func runInit(sh, command string) {
 	env := &runtime.Terminal{}
 	env.Init(flags)
 
-	cache.Init(sh, cache.NewSession, cache.Persist)
-
 	template.Init(env, cfg.Var, cfg.Maps)
 
 	defer func() {
@@ -161,3 +165,12 @@ func getFullCommand(cmd *cobra.Command, args []string) string {
 
 	return cmdPath
 }
+
+func initCache(sh string) {
+	if !printOutput && (sh == shell.PWSH || sh == shell.ELVISH) {
+		cache.Init(sh)
+		return
+	}
+
+	cache.Init(sh, cache.NewSession, cache.Persist)
+}
